﻿package MT::Plugin::EntryAsset;
use strict;
use MT;
use MT::Plugin;

our $VERSION = '0.1';

use base qw( MT::Plugin );

@MT::Plugin::EntryAsset::ISA = qw(MT::Plugin);

my $plugin = new MT::Plugin::EntryAsset({
    name => 'EntryAsset',
    id => 'entryasset',
    description => 'Add \'Edit EntryAsset\' links to edit entry screen.',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    'version' => $VERSION,
});

MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_param.edit_entry'
                => \&_entry_param,
            'MT::App::CMS::template_source.edit_entry'
                => \&_entry_source,
            'MT::App::CMS::template_source.edit_asset'
                => \&_edit_asset_dialog,
            'MT::App::CMS::template_output.edit_asset'
                => \&_edit_asset_output,
        },
   });
}

sub _entry_param {
    my ( $cb, $app, $param, $tmpl ) = @_;
    my $q = $app->param;
    my $blog_id = $app->blog->id;
    my $entry_id = $q->param('id');
    if ( $entry_id ) {
        my @assets = MT::Asset->load(undef, { join => MT::ObjectAsset->join_on(undef, {
            asset_id => \'= asset_id', object_ds => 'entry', object_id => $entry_id })});
        if ( @assets ) {
            my $pointer_field = $tmpl->getElementById('category');
            my $nodeset = $tmpl->createElement('app:widget', { id => 'entryasset-widget', label => $plugin->translate('Asset') , required => 0 });
            my $innerHTML = '<ul id="entry-asset-list">';
            for my $asset ( @assets ) {
                my $label;
                if ( $asset->label ) {
                    $label = $asset->label;
                } else {
                    $label = $asset->file_name;
                }
                $innerHTML .= '<a title="<mt:var name="phrase_edit">" href="javascript:void(0)" onclick="return openDialog(false, \'view\', \'_type=asset&amp;id=';
                $innerHTML .= $asset->id . '&amp;blog_id=<mt:var name="blog_id">&amp;asset_dialog=1\')">';
                $innerHTML .= '<li><img src="<mt:var name="static_uri">images/nav_icons/color/new-entry.gif" alt="<mt:var name="phrase_edit">" width="17" height="15" />';
                $innerHTML .= ' <span>' . $label . '</span></a></li>';
            }
            $innerHTML .= '</ul>';
            $nodeset->innerHTML($innerHTML);
            $tmpl->insertAfter($nodeset, $pointer_field);
        }
    }
}

sub _entry_source {
    my ( $cb, $app, $tmpl ) = @_;
    my $insert_css = '<mt:setvarblock name="html_head" append="1">';
    my $css =<<CSS;
    <mt:setvarblock name="html_head" append="1">
    <style type="text/css">
        #entryasset-widget .widget-header {
            margin-left   : 0px !important;
            margin-bottom : -1px;
        }
        #entryasset-widget .widget-content-inner {
            padding : 3px 3px 0px 10px !important;
            border  : 1px solid #D0DDE6;
        }
        #entry-asset-list li span,
        #entry-asset-list li img {
            vertical-align:middle;
        }
        #entry-asset-list {
            margin-bottom : 0px;
        }
    </style>
CSS
    $$tmpl =~ s/$insert_css/$css/;
}

sub _edit_asset_dialog {
    my ($cb, $app, $tmpl) = @_;
    my $q = $app->param;
    my $flag = $q->param('asset_dialog');
    if ( $flag ) {
        my $include = '<mt:include name="include/header.tmpl">';
        my $dialog = '<mt:include name="dialog/header.tmpl">';
        $dialog .= '<div style="width:50%">';
        $$tmpl =~ s/$include/$dialog/;
        $dialog = '<mt:include name="dialog/footer.tmpl">';
        $include = '<mt:include name="include/footer.tmpl">';
        $$tmpl =~ s/$include/$dialog/;
        my $button = '<__trans phrase="Save Changes"></button>';
        my $cancel =<<BUTTON;
        <__trans phrase="Save Changes"></button>
        <button
            onclick="closeDialog(); return false"
            type="submit"
            accesskey="x"
            title="<__trans phrase="Cancel"> (x)"
            ><__trans phrase="Cancel"></button>
BUTTON
        $$tmpl =~ s/$button/$cancel/;
    }
}

sub _edit_asset_output {
    my ($cb, $app, $tmpl) = @_;
    my $q = $app->param;
    my $icon = $app->static_path . 'images/asset/file.gif';
    my $icon_v = $app->static_path . 'images/asset/video.gif';
    my $icon_a = $app->static_path . 'images/asset/audio.gif';
    my $flag = $q->param('asset_dialog');
    if ( $flag ) {
        my $head = '</head>';
        my $css .=<<"CSS";
    <style type="text/css">
        .asset-thumb-metadata {background-color:white;text-align:center}
        .asset-type-image {background-color:transparent !important}
        .asset-type-file {background-color:transparent !important}
        .asset-type-video {background-color:transparent !important}
        .asset-type-audio {background-color:transparent !important}
        .asset-type-image .asset-thumb-inner{ background-color:black;text-align:center }
        .asset-type-file .asset-thumb-inner { height:250px;text-indent:-10000px; background-color:#EEEEEE;
                                              background-image:url($icon);
                                              background-repeat:no-repeat;
                                              background-position:120px 120px;
                                              border:1px solid gray; }
        .asset-type-video .asset-thumb-inner{ height:250px;text-indent:-10000px; background-color:#EEEEEE;
                                              background-image:url($icon_v);
                                              background-repeat:no-repeat;
                                              background-position:120px 120px;
                                              border:1px solid gray; }
        .asset-type-audio .asset-thumb-inner{ height:250px;text-indent:-10000px; background-color:#EEEEEE;
                                              background-image:url($icon_a);
                                              background-repeat:no-repeat;
                                              background-position:120px 120px;
                                              border:1px solid gray; }
    </style>
</head>
CSS
        $$tmpl =~ s/$head/$css/;
        my $return_args = '<input type="hidden" name="return_args" value="';
        $$tmpl =~ s/($return_args.*?)"/$1&amp;asset_dialog=1"/;
    }
}

1;